#[non_exhaustive]pub enum ServerError {
Bind {
addr: String,
source: Error,
},
Serve(Error),
}Expand description
Error binding a listener or running the server loop.
Non-exhaustive: this crate is shared plumbing consumed by multiple
product surfaces, so new failure variants may be added without that
being a breaking change for callers that only use ?/Display/
Error::source rather than exhaustively matching.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Bind
Binding addr failed (e.g. already in use, permission denied).
Serve(Error)
The axum::serve run loop returned an error.